@@ -116,8 +116,8 @@ int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, c
 	printf("\n\n");
 */
 
-	for (i=0;i<blk_size;i++) printf("%02x ", curr_block[i]);
-	printf("\n");
+//	for (i=0;i<blk_size;i++) printf("%02x ", curr_block[i]);
+//	printf("\n");
 
 	retval=compress(out_block, &dest_size, tmp_block, m);
 	if (retval!=Z_OK) {
@@ -159,8 +159,8 @@ int comp_mzlib2_decompress(unsigned char *prev_block, unsigned char *curr_block,
 		out_block[m++]=repl_val&0xff;
 	}
 
-        for (i=0;i<m;i++) printf("%02x ", out_block[i]);
-        printf("\n");
+//        for (i=0;i<m;i++) printf("%02x ", out_block[i]);
+//        printf("\n");
 
 
 	return(m);
