@@ -34,6 +34,9 @@
 #include "dact.h"
 #include "algorithms.h"
 #include "endian.h"
+#ifdef CHECK_VERSION
+#include "net.h"
+#endif
 
 #ifdef HAVE_GETOPT
 extern char *optarg;
@@ -41,8 +44,8 @@ extern int optind, opterr, optopt;
 #endif
 
 int print_help(int argc, char **argv) {
-	fprintf(stderr, "DACT version %i.%i.%i by Roy Keene at Netfuel Design (rkeene@netfueldesign.com).\n",DACT_VER_MAJOR,DACT_VER_MINOR,DACT_VER_REVISION);
-	fprintf(stderr, "Usage:\n\t%s [-sdfv[v[v]]clc] [-e XX] [-b XX] [--] <filename> [outfile]\n",argv[0]);
+	fprintf(stderr, "DACT version %i.%i.%i by Roy Keene at Netfuel Design (rkeene@netfueldesign.com).\n\n",DACT_VER_MAJOR,DACT_VER_MINOR,DACT_VER_REVISION);
+	fprintf(stderr, "Usage:\n\t%s [-sdfv[v[v]]Clc] [-e XX] [-b XX] [--] <filename> [outfile]\n\n",argv[0]);
 	fprintf(stderr, "  -s\tDisplay statistics about file (Don't compress or decompress.)\n");
 	fprintf(stderr, "  -d\tDecompress instead of compressing.\n");
 	fprintf(stderr, "  -f\tForce overwriting existing files.\n");
@@ -56,6 +59,48 @@ int print_help(int argc, char **argv) {
 }
 
 
+FOUR_BYTES is_latest (void) {
+#ifdef CHECK_VERSION
+	int fd;
+	char ver_maj[4]={0,0,0,0}, ver_min[4]={0,0,0,0}, ver_rev[4]={0,0,0,0};
+	char bigbuf[1024], *smallbuf;
+	int vers[3];
+	int past=0;
+
+	fd=createconnection_tcp("keene.netfueldesign.com", 80);
+	write(fd, "GET /devel/dact/VERSION HTTP/1.1\n", 33);
+	write(fd, "Host: keene.netfueldesign.com\n\n", 31);
+	read(fd, &bigbuf,1024);
+
+	strtok(bigbuf, "\n");
+	while ((smallbuf=strtok(NULL, "\n"))!=NULL) {
+		if (strlen(smallbuf)==1) past=1;
+		if (strlen(smallbuf)==9 && past==1) {
+			memcpy(ver_maj,smallbuf,3);
+			memcpy(ver_min,smallbuf+3,3);
+			memcpy(ver_rev,smallbuf+6,3);
+			past=2;
+		}
+	}
+	close(fd);
+
+	if (past!=2) return(1);
+
+	vers[0]=atoi(ver_maj);
+	vers[1]=atoi(ver_min);
+	vers[2]=atoi(ver_rev);
+
+	if (vers[0]!=DACT_VER_MAJOR || vers[1]!=DACT_VER_MINOR || vers[2]!=DACT_VER_REVISION) {
+		return((vers[0]<<16)|(vers[1]<<8)|vers[2]);
+	} else {
+		return(0);
+	}
+#else
+	return(0);
+#endif
+}
+
+
 
 int main(int argc, char **argv) {
 	char in_filename[128], out_filename[128];
@@ -70,6 +115,7 @@ int main(int argc, char **argv) {
 	char option_old=0;
 	char ch;
 	FOUR_BYTES file_size_real=0, file_size, out_file_size, in_magic;
+	FOUR_BYTES version_latest;
 	int stat_cnt[256];
 	int in_fd, out_fd=-1;
 	int i,x=0;
@@ -92,6 +138,12 @@ int main(int argc, char **argv) {
 	option_verbose=1;
 #endif
 
+	if ((version_latest=is_latest())!=0) {
+		fprintf(stderr, "NOTE:\n");
+		fprintf(stderr, "  There is a newer version of DACT: %i.%i.%i\n", version_latest>>16, (version_latest>>8)&0xff, version_latest&0xff);
+		fprintf(stderr, "  http://keene.netfueldesign.com/devel/dact.tar.gz is the latest version.\n\n");
+	}
+
 #ifdef HAVE_GETOPT
 	while ((ch = getopt(argc,argv,"dfvClshce:b:")) != -1) {
 #else
@@ -179,8 +231,7 @@ int main(int argc, char **argv) {
 		} else {
 			if (isatty(STDOUT_FILENO)) {
 				if (isatty(in_fd)) {
-					fprintf(stderr, "%s: In and out are both terminals.\n",argv[0]);
-					return(-1);
+					return(print_help(argc,argv));
 				}
 				if (mode==DACT_MODE_COMPR) {
 					strncpy(out_filename,in_filename,sizeof(out_filename)-4);
