@@ -61,6 +61,7 @@ void int_sort_fast (FOUR_BYTES array[], unsigned int elements) {
 	for (i=0;i<elements;i++) array[i]|=(i<<16);
 
 	for (i=0;i<elements;i++) {
+		if ((array[i]&0xffff)==0) continue;
 		for (x=0;x<cnt+1;x++) {
 			if ((array[i]&0xffff) > (hold_array[x]&0xffff)) {
 				if (x<cnt) {
@@ -79,11 +80,12 @@ void int_sort_fast (FOUR_BYTES array[], unsigned int elements) {
 
 /*
 
-	Sort really quickly, apprx. 
+	Sort really quickly
 
 */
 void int_sort_really_fast (FOUR_BYTES array[], unsigned int elements) {
 	TWO_BYTES list_items[0x10000];
+//	TWO_BYTES list_items[0x10000][0x10001];
 	int i,f=0,m;
 
 
